@@ -1,7 +1,6 @@
 import os
 from os.path import abspath, exists, join
 from setuptools import find_packages, setup as _setup
-from setuptools import Extension
 from setuptools_scm import get_version
 import toml
 
@@ -134,6 +133,7 @@ class Setup:
         readme_rst = join(self.root, "README.rst")
         readme_md = join(self.root, "README.md")
         if exists(readme_rst):
+            self.setup_kwargs["long_description_content_type"] = "text/x-rst"
             with open(readme_rst) as fp:
                 self.setup_kwargs["long_description"] = fp.read()
 
